<?php
/*
    Plugin Name: Notifixio.us
    Plugin URI: http://wordpress.org/extend/plugins/notifixious-plugin/
    Description: This plugin allow your blog to send notifications to your followers on Notifixious through the channels they use (Email, SMS, Instant Messaging : MSN, AIM, GTalk, Yahoo! Messenger...). Once activated, please go to <a href="/wp-admin/options-general.php?page=Options%20Notifixious"> to set it up</a>! Finally : don't forget to <a href="/wp-admin/widgets.php">use our Widget</a> as well to allow your users to subscribe to your blog!
    Version: 0.2
    Author: Mathieu BUONOMO
    Author URI: http://www.mathieubuonomo.com
*/
?>
<?php

/* Generic stuff */
if ( !defined('WP_CONTENT_URL') ) {
    define('WP_CONTENT_URL', get_option('siteurl') . '/wp-content');
}
if ( !defined('PLUGINDIR') ) {
    define( 'PLUGINDIR', 'wp-content/plugins' ); // Relative to ABSPATH.  For back compat.
}

function notifixious_plugin_basename($file) {
    $file = dirname($file);

    // From WP2.5 wp-includes/plugin.php:plugin_basename()
    $file = str_replace('\\','/',$file); // sanitize for Win32 installs
    $file = preg_replace('|/+|','/', $file); // remove any duplicate slash
    $file = preg_replace('|^.*/' . PLUGINDIR . '/|','',$file); // get relative path from plugins dir

    if ( strstr($file, '/') === false ) {
        return $file;
    }

    $pieces = explode('/', $file);
    return !empty($pieces[count($pieces)-1]) ? $pieces[count($pieces)-1] : $pieces[count($pieces)-2];
}

define('NOTIFIXIOUS_PLUGIN_URL', WP_CONTENT_URL . '/plugins/' . notifixious_plugin_basename(__FILE__));

/* End of generic stuff */


/* Defining functions */

function send_request_to_notifixious($url = "", $method = "GET", $params = "")
{
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_VERBOSE, 1);
    if(params!="")
    {
        curl_setopt($ch, CURLOPT_POSTFIELDS,$params);
    }
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false); 
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false); 
    curl_setopt($ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
    if($method == "POST")
    {
        curl_setopt($ch, CURLOPT_POST, 1);
    }
    else
    {
        curl_setopt($ch, CURLOPT_HTTPGET, 1);
    }
    // Go for it!!!
    $result = curl_exec($ch);
    $error_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    // close curl
    curl_close($ch);
    $xml = simplexml_load_string($result);
    $results["xml"] = $xml;
    $results["http_code"] = $error_code;
    return $results;
}



function register_blog_on_notifixious()
/*  This method registers the blog on Notifixious
    In case of success, the SourceId is saved, and the Claim is set to false
    In case of failure, the SourceId stays at 0, and Claim is set to false as well
*/
{
    $url = "http://notifixio.us/sources/generate.xml";
    $params = "source[source_url]=".get_bloginfo('rss2_url');
    $results = send_request_to_notifixious($url, "POST" ,$params);
    if($results["http_code"]!="200")
    {
        update_option('notifixiousSourceId','0', '', 'no');
        update_option('notifixiousRegistered','0', '', 'no');
        return false;
    }
    else
    {
        $source_id = $results["xml"]->source[0]->id; 
        if($source_id > 0)
        {
            update_option('notifixiousSourceId',''.$source_id.'', '', 'no');
            update_option('notifixiousRegistered','1', '', 'no');
            update_option('notifixiousClaimed','0', '', 'yes');
            return true;
        }
        else
        {
            update_option('notifixiousSourceId','0', '', 'no');
            update_option('notifixiousRegistered','0', '', 'no');
            return false;
        }
    }

}

function claim_blog_on_notifixious($login, $password, $source_id)
/*  This methods claims the blog on notifixious. For now, the method used is a file, which will change very soon.
*/
{
    $url = "http://".$login.":".$password."@notifixio.us/sources/".$source_id."/ownerships/new.xml";
    $results = send_request_to_notifixious($url, "GET"); 
	$tagname = $results["xml"]->method[1]->hash->description->{'tag-name'}[0];
	$tagcontent = $results["xml"]->method[1]->hash->description->{'tag-content'}[0];
	add_option('notifixiousTagName', $tagname, '', '0');
	add_option('notifixiousTagContent', $tagcontent, '', '0');
    $url = "http://".$login.":".$password."@notifixio.us/sources/".$source_id."/ownerships.xml";
    $params = "method=tag";
    $results = send_request_to_notifixious($url, "POST", $params);
    
    if($results["http_code"]!="201")
    {
        update_option('notifixiousClaimed','0', '', 'yes');
        return false;
    }
    else
    {
        $ownership_user_id = $results["xml"]->{'user-id'};
        $ownership_source_id = $results["xml"]->{'source-id'};
        if($ownership_user_id != 0 && $ownership_source_id == $source_id)
        {
            update_option('notifixiousClaimed','1', '', 'yes');
            return true;
        }
        else
        {
            update_option('notifixiousClaimed','0', '', 'yes');
            return false;
        }
    }
}

function check_login($login = "", $password = "")
/*  This method checks a login and a user name
In case of success, the notifixiousLoginValid is set to true, else it stays false
*/
{
    $url = "http://notifixio.us/session.xml";
    $params = "login=".$login."&password=".$password;
    $results = send_request_to_notifixious($url, "POST", $params);
    if($results["http_code"]!= "201")
    {
        # Wrong login/password
        update_option('notifixiousLoginValid','0', '', 'yes');
        return false;
    }
    else
    {
        # Good, let's check that the login is the same as the one provided ;-)
        if($results["xml"]->login == $login)
        {
            update_option('notifixiousLoginValid','1', '', 'yes');
            return true;
        }
        else
        {
            update_option('notifixiousLoginValid','0', '', 'yes');
            return false;
        }
    }
}

/* End of functions */

/* Main Code!  */

$id = get_option('notifixiousSourceId');
$claim = 0; #get_option('notifixiousClaim');
$login = get_option('notifixiousLogin');
$notifixiousLoginValid = get_option('notifixiousLoginValid');

if(!$notifixiousLoginValid)
{
    $login = get_option('notifixiousLogin');
    $password = get_option('notifixiousPassword');
    $notifixiousLoginValid = check_login($login, $password);
}

if($_GET["register_blog"])
{
    register_blog_on_notifixious();
}

if($_GET["claim_blog"])
{
    claim_blog_on_notifixious($login, get_option('notifixiousPassword'), get_option('notifixiousSourceId'));
}


?>
<div class="wrap">
    <h2><?php _e('Notifixious Settings') ?></h2>
    <p>Please enter your Notifixious login information. If you have forgotten your password, please <a href= "http://notifixio.us/forgot_password">request a new one here</a>.</p>
    <p>Don't forget to <a href="/wp-admin/widgets.php">install our widget</a> as well to allow your readers to choose the channels on which they want to be notified!</a>
    <form method="post" action="options.php">
        <?php wp_nonce_field('update-options'); ?>
        <table class="form-table">
            <tr>
                <th><label for="notifixiouslogin">Login</label></th>
                <td><input type="text" name="notifixiousLogin" id="notifixiousLogin" value="<?php echo get_option('notifixiousLogin'); ?>" /></td>
            </tr>
            <tr>
                <th><label for="notifixiouspassword">Password</label></th>
                <td>
                    <input type="password" name="notifixiousPassword" id="notifixiousPassword" value="<?php echo get_option('notifixiousPassword'); ?>" />
                    <div>
                        <?php
                            if($notifixiousLoginValid)
                            {
                                ?>
                                    <img src="<?php echo NOTIFIXIOUS_PLUGIN_URL; ?>/accept.png" style="margin:3px; float:left;"> Login checked and valid.
                                <?php
                            }
                            else
                            {
                                ?>
                                    <img src="<?php echo NOTIFIXIOUS_PLUGIN_URL; ?>/delete.png" style="margin:3px; float:left;"> Wrong login or password.
                                <?php
                            }
                        ?>
                    </div>
                </td>
            </tr>
        </table>
        <input type="hidden" name="action" value="update" />
        <input type="hidden" name="notifixiousLoginValid" value="0" />
        <input type="hidden" name="page_options" value="notifixiousLogin,notifixiousPassword,notifixiousLoginValid" />
        <p class="submit">
            <input type="submit" name="Submit" value="<?php _e('Save Changes') ?>" />
        </p>
    </form>
    <table class="form-table">
        <tr>
            <th><label>Generate Source</label></th>
            <td>
                <?php
                    if(get_option('notifixiousRegistered'))
                    {
                        ?>
                            <img src="<?php echo NOTIFIXIOUS_PLUGIN_URL; ?>/accept.png" style="margin:3px; float:left;">You blog has successfully been <a href="http://www.notifixio.us/sources/<?php echo $id; ?>">registered with Notifixio.us</a>! 
                        <?php
                    }
                    else
                    {
                        ?>
                            <img src="<?php echo NOTIFIXIOUS_PLUGIN_URL; ?>/delete.png" style="margin:3px; float:left;">Your blog hasn't been registered with Notifixious. <a href="/wp-admin/options-general.php?page=Options%20Notifixious&register_blog=true">Register now!</a>
                            <p style="margin: 5px 10px;">You need to add your blog to the list of available sources on Notifixious to be able to send Notifications when you publish a new post.</p>
                        <?php
                    }
                ?>
            </td>
        </tr>
        <tr>
            <th><label>Claim Source</label></th>
            <td>
            <?php 
    if(get_option('notifixiousClaimed'))
    {
        ?>
        <img src="<?php echo NOTIFIXIOUS_PLUGIN_URL; ?>/accept.png" style="margin:3px; float:left;">You blog has successfully been claimed! You can know publish new posts that will be notified to all your readers who subscribed to Notifixious!
        <?php
}
else
{
    ?>
                <img src="<?php echo NOTIFIXIOUS_PLUGIN_URL; ?>/delete.png" style="margin:3px; float:left;">This blog has not been claimed. <a href="/wp-admin/options-general.php?page=Options%20Notifixious&claim_blog=true">Claim it know!</a> <p style="margin: 5px 10px;">Once your blog has been registered, we need to check that you actually own it. Once this is done, you can publish new post that will be notified to all your readers!</p>
    <?php
}
?>
            </td>
        </tr>
    </table>
</div>